==> breeze_website_builder_6.5.02.tar.gz: manage/plugins/lang/gallery/tr.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Işık Gallary Parametreleri yönetme");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "Galeri Yönet");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Resmin Genişliği");
define('MANAGE_GALLERY_FULL_HEIGHT', "Resmin Yüksekliği");
define('MANAGE_GALLERY_THUMB_WIDTH', "Küçük Resim Genişliği");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Küçük Resim Yüksekliği");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Başparmak Boyut Oranını Koru");
define('MANAGE_GALLERY_SHOW_TITLES', "göster Başlıklar");
define('MANAGE_GALLERY_DISABLE_SORT', "Devre Dışı Bırak sırala");
define('MANAGE_GALLERY_DELETE_IMAGE', "Görüntü silme");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Sipariş sırala kaydet");
define('MANAGE_GALLERY_PUBLISH_MSG', "yayımlamak için &#39;Güncelle&#39; tıklayın <br /> Yüklediğiniz görüntüler.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Tüm görüntüler resized edilmiş ve ayarlar kaydedildi.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Bir hata görüntüler yeniden boyutlandırma veya ayarları kaydetmeden oldu.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Resminiz (ler) yüklendi.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "resim (ler) yüklenirken bir hata oluştu.");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Eğer yüklemeye çalıştığınız dosya bir görüntü değil.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Eğer yüklemeye çalıştığınız dosya çok büyük.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "başlık kaydedildi.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Eğer görüntüyü silmek istediğinizden emin misiniz");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Görüntü silindi.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Görüntüyü silinirken bir hata oluştu.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "kaydetme parametrelerini ve görüntüleri yeniden boyutlandırma, lütfen bekleyin ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Yükleme, lütfen bekleyin ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "sıralama kaydedilmedi. sıralama düzenini kaydetmek istiyor musunuz?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "görüntü sıralama kaydedildi.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Görüntü tür kaydedilirken bir hata oluştu.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/tr.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Işık Gallary Parametreleri yönetme");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "Galeri Yönet");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Resmin Genişliği");
define('MANAGE_GALLERY_FULL_HEIGHT', "Resmin Yüksekliği");
define('MANAGE_GALLERY_THUMB_WIDTH', "Küçük Resim Genişliği");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Küçük Resim Yüksekliği");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Başparmak Boyut Oranını Koru");
define('MANAGE_GALLERY_SHOW_TITLES', "göster Başlıklar");
define('MANAGE_GALLERY_DISABLE_SORT', "Devre Dışı Bırak sırala");
define('MANAGE_GALLERY_DELETE_IMAGE', "Görüntü silme");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Sipariş sırala kaydet");
define('MANAGE_GALLERY_PUBLISH_MSG', "yayımlamak için &#39;Güncelle&#39; tıklayın <br /> Yüklediğiniz görüntüler.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Tüm görüntüler resized edilmiş ve ayarlar kaydedildi.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Bir hata görüntüler yeniden boyutlandırma veya ayarları kaydetmeden oldu.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Resminiz (ler) yüklendi.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "resim (ler) yüklenirken bir hata oluştu.");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Eğer yüklemeye çalıştığınız dosya bir görüntü değil.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Eğer yüklemeye çalıştığınız dosya çok büyük.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "başlık kaydedildi.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Eğer görüntüyü silmek istediğinizden emin misiniz");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Görüntü silindi.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Görüntüyü silinirken bir hata oluştu.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "kaydetme parametrelerini ve görüntüleri yeniden boyutlandırma, lütfen bekleyin ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Yükleme, lütfen bekleyin ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "sıralama kaydedilmedi. sıralama düzenini kaydetmek istiyor musunuz?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "görüntü sıralama kaydedildi.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Görüntü tür kaydedilirken bir hata oluştu.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "Yüklemeye çalıştığınız dosya &#39;upload_max_filesize&#39; veya &#39;post_max_size&#39; PHP ayarlarından daha büyük. Bu sınırları artırmak için sistem yöneticinize başvurun.");
?>
